### Name: ListHyperGParams-class
### Title: Classes for quick GO/KEGG/CHR/miRNA target enrichment
###   calculation of multiple gene sets.
### Aliases: ListHyperGParams CHRListHyperGParams GOListHyperGParams
###   KEGGListHyperGParams miRNAListHyperGParams ListHyperGParams-class
###   CHRListHyperGParams-class GOListHyperGParams-class
###   KEGGListHyperGParams-class miRNAListHyperGParams-class drive drive<-
###   drive,ListHyperGParams-method drive,GOListHyperGParams-method
###   drive,KEGGListHyperGParams-method drive,CHRListHyperGParams-method
###   drive,miRNAListHyperGParams-method
###   drive<-,ListHyperGParams,logical-method
###   drive<-,GOListHyperGParams,logical-method
###   drive<-,KEGGListHyperGParams,logical-method
###   drive<-,CHRListHyperGParams,logical-method
###   drive<-,miRNAListHyperGParams,logical-method
###   hyperGTest,ListHyperGParams-method
###   hyperGTest,CHRListHyperGParams-method
###   hyperGTest,KEGGListHyperGParams-method
###   hyperGTest,GOListHyperGParams-method
###   hyperGTest,miRNAListHyperGParams-method
###   makeValidParams,ListHyperGParams-method
###   makeValidParams,CHRListHyperGParams-method
###   makeValidParams,KEGGListHyperGParams-method
###   makeValidParams,GOListHyperGParams-method
###   makeValidParams,miRNAListHyperGParams-method
###   conditional,GOListHyperGParams-method
###   conditional<-,GOListHyperGParams,logical-method
###   ontology<-,GOListHyperGParams,character-method
###   ontology,GOListHyperGParams-method
### Keywords: cluster

### ** Examples

# GO enrichment, "by hand"
# Load data first
data(ALLModulesSmall)

# Create gene sets
library(hgu95av2.db)
genes <- getFeatureNames(ALLModulesSmall)
entrez <- lapply(genes, function(x) na.omit(unlist(mget(x,
              hgu95av2ENTREZID))))

# Create universe
universe <- na.omit(unlist(mget(featureNames(ALLModulesSmall),
              hgu95av2ENTREZID)))

# Create parameter object
param <- new("GOListHyperGParams", geneIds=entrez, universeGeneIds=universe,
             pvalueCutoff=0.01, drive=FALSE, ontology="BP",
             conditional=FALSE, testDirection="over",
             annotation=annotation(ALLModulesSmall))

# Do the calculation
GOBP <- hyperGTest(param)

# Inspect the result
GOBP
summary(GOBP)[[1]]



